@@ -24,19 +24,25 @@ c
 
           record /ptcl/ pj, tg, pj2, a(nmax), cmspj, cmstg
           record /ptcl/ compj, comtg
+          record /ptcl/ compjcms, comtgcms, cmspsave
 c             projectile and target information (both befor
 c             and after collision ) in different system.
 c
           integer k, icon, ntp, j, nevent, nuccharge, ntp0
           real*8 x, y, eta, ek1
+          real*8 xcms,  ek1cms
           integer NEVTS,NPMASS,NPCHAR,NTMASS,NTCHAR,IDP,IEMU
           real*8 EPN
           real*4  x2, y2, z2
           real*4  ext/10./
-
+          record /ptcl/ labp
 
           real*8  energy
-          real pt, ptx, pty, ke, teta
+          real*8  gamma, beta
+
+          real pt, ptx, pty, ke, teta, pz, pzcms, ptcms
+          real  kecms, tetacms
+
           character*100  msg
           character*100  tracefile
           character*80  prefix
@@ -70,7 +76,7 @@ c
      *              ia, iz, cms, xbyp
           call cqUHookc(2, input)
           call cqUHookc(3, prefix)
-c          write(ErrorOut,*) input
+          write(ErrorOut,*) input
 c
 cUserHooki = 0,       0,      0,       0,      0,        0,       0    0
 c         OmegaBaryon Dmeson  eta      gzai   lambda    lambdac  pi0  sigma
@@ -101,8 +107,8 @@ c
      *      ' intmodel=', IntModel(1:klena(IntModel)),
      *      '"' 
             write(*, '(a)') 
-     *     '# "x" "y" "eta" "pt" "code" "subcode" "charge"'//
-     *     ' "mult" "teta" "K.E" "ev#"'
+     * '# "X" "Xcms" "Pz" "Pzcms" "y" "eta" "pt" "code" '//
+     * ' "subcd" "chg" "mult" "teta" "tetacms" "K.E" "K.Ecms" "ev#"'
 c           defalut trace.  fix the dirctor
          else
           if(TraceDir .eq. ' ') then
@@ -123,6 +129,7 @@ c            cms is for h-p
                 energy = ( roots**2/(2*masp) -  masp ) * subcode
              endif
           endif
+
 c              set projectile energy and momentum
           pj.fm.p(1) =0.
           pj.fm.p(2) =0.
@@ -174,29 +181,40 @@ c                        the last / is needed.
 
 c              This is to form  Cmsp
           call chncol(pj2, tg, a, ntp, icon)
+          if( icon .ne. 0 ) then
+             write(msg,*) ' cms cannot be formed' 
+             call cerrorMsg(msg,0)
+          endif
+
+          cmspsave = Cmsp
 
           call rnd1i(InitRN)     ! random number init.
 c             fix model by seeing the proj. energy.
           call cfixModel(pj)
-          if(cms) then
-             call cbst1(1, Cmsp,  pj, cmspj)
-             ek1 = cmspj.fm.p(3)
-             compj = cmspj
-             call cbst1(2, Cmsp,  tg, cmstg)
-             comtg = cmstg
+          compj = pj
+          comtg = tg
+          if(xbyp) then
+             ek1 = pj2.fm.p(3)
           else
-             compj = pj
-             comtg = tg
-             if(xbyp) then
-                ek1 = pj.fm.p(3)
-             else
-                ek1 = pj.fm.p(4) -  pj.mass
-             endif
+             ek1 = pj2.fm.p(4) -  pj2.mass
           endif
 
-          if(pj.code .eq. kgnuc ) then
-             ek1 = ek1 / pj.subcode
-          endif
+
+          call cbst1(1, cmspsave,  pj2, cmspj)
+	  if(xbyp) then
+	     ek1cms = cmspj.fm.p(3)
+	  else	
+	     ek1cms = cmspj.fm.p(4)-cmspj.mass
+	  endif	
+  	  if(pj.code .eq. kgnuc) then
+            call cbst1(1, cmspsave,  pj, cmspj)
+          endif	
+
+          compjcms = cmspj
+          call cbst1(2, cmspsave,  tg, cmstg)
+          comtgcms = cmstg
+
+
 
           if(SeedFile .ne. ' ') then
              call copenfw(SeedFileDev, SeedFile, icon)
@@ -217,18 +235,18 @@ c             fix model by seeing the proj. energy.
                 call cheavyInt(pj, ia, iz, a, ntp0)
              endif
 c/////////////
-             tgtA = ia
-             tgtZ = iz
+c             tgtA = ia
+c             tgtZ = iz
 c             call cxsecGheisha(pj, tgtA, tgtZ, xs)
 c            write(0,*) xs
 c
 c
 c            call ctotx(pj, tgtA,  xs)
-
+c
 c            write(0,*) xs
-c            call cprotonAXsec(tgtA, pj.fm.p(4)-pj.mass, xs)
-c            write(0,*) xs
-
+c          tgtA= 14.83   
+c          call cprotonAXsec(tgtA, pj.fm.p(4)-pj.mass, xs)
+c          write(0,*)sngl(sqrt(pj.fm.p(4)**2-pj.mass**2)), sngl(xs)
 c////////////
 
 
@@ -248,36 +266,46 @@ c                   draw projectile
              endif
 
              do j = 1, ntp
-                if(cms) then
-                   call cbst1(j, Cmsp, a(j), a(j))
-                endif
                 if(Trace .eq. 0 ) then
                    ptx = sngl(a(j).fm.p(1))
                    pty = sngl(a(j).fm.p(2))
+                   pz =  a(j).fm.p(3)
                    if(xbyp) then
                       x =  a(j).fm.p(3) / ek1 
                    else
                       x =( a(j).fm.p(4)- a(j).mass)/ek1
                    endif
-
                    pt =sqrt(a(j).fm.p(1)**2 + a(j).fm.p(2)**2)
                    teta = atan2( pt, sngl(a(j).fm.p(3)) ) *
      *               180./3.1415
                    ke = a(j).fm.p(4)-a(j).mass
-                   if(.not. cms) then
-c                    transform to CMS.  for y, eta, even if not cms 
-                      call cbst1(j, Cmsp,  a(j), a(j))
-                      call cyeta(a(j), y, eta)
-                   endif
 
-                   write(*, '(4g13.3, 3i3, i5, 2g13.3, i8)' )
-     *               sngl(x), sngl(y),  sngl(eta),  pt, 
+c                    transform to CMS.
+                   labp = a(j)
+                   call cbst1(j, cmspsave,  a(j), a(j))
+                   call cyeta(a(j), y, eta)
+
+                   pzcms =  a(j).fm.p(3)
+                   if(xbyp) then
+                      xcms =  pzcms / ek1cms 
+                   else
+                      xcms =( a(j).fm.p(4)- a(j).mass)/ek1cms
+                   endif
+                   ptcms =sqrt(a(j).fm.p(1)**2 + a(j).fm.p(2)**2)
+                   tetacms = atan2( ptcms, sngl(a(j).fm.p(3)) ) *
+     *               180./3.1415
+                   kecms = a(j).fm.p(4)-a(j).mass
+
+                   write(*, '(7g13.3, 3i3, i6, 4g13.3, i8)' )
+     *               sngl(x), sngl(xcms), pz, pzcms, sngl(y), 
+     *               sngl(eta),  pt, 
      *               a(j).code, a(j).subcode, a(j).charge,
-     *               ntp, teta,
-     *               ke,  k
+     *               ntp, teta, tetacms,
+     *               ke, kecms, k
                 else
                    call cvisualizeTrack(a(j), 0, ext*0.35)
                 endif
+
              enddo
              if(Trace .ne. 0 ) then
                 close(TraceDev)
@@ -336,6 +364,7 @@ c
 c       particles such as sigma etc in 'a' are decayed if requested
 c      
       record /ptcl/ a(nmax)  ! input/output. 
+
       integer nin      ! input ptcls in a.
       integer n        ! output. ptcls in a. n >= nin.
 
