@@ -4,10 +4,13 @@ c            particle  production
 #define  ZCONDC
 #define  INCLUSIVE 0
 
-c   For Epics on NEXTSTEP, dpmjet is too large and a valid executable
-c   cannot be made.  If you want to make a library for Epics on NEXTSTEP  
-c   you have to make the next 0. (Cosmos on NEXTSTEP can use dpmjet).
+c   dpmjet cannot be used on NEXTSTEP, so
+c   you have to make the next 0. 
+#ifdef NEXT486
+#define  USEDPMJET    0
+#else
 #define  USEDPMJET    1
+#endif
 c            make DEBUG > 0 depending on the debug purpose. 
 
 #define  DEBUG 0
