@@ -15,7 +15,7 @@ c       ***************************************** stave  cont info
 
       PrevEventNo = EventNo    ! current event no.
       call rnd1s(InitRN)  !  current seed.
-      call copenfw(TempDev, ContFile, icon)
+      call copenNLfw(TempDev, ContFile, icon)
 c      open(TempDev, file=ContFile, form='formatted')
       call cwriteParam(TempDev, 1)
       close(TempDev)
